Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(379)

Unified Diff: services/ui/ws/window_manager_display_root.h

Issue 2877233002: Remove the i from visib[i]le. (Closed)
Patch Set: merge with tot Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/ws/cursor_unittest.cc ('k') | services/ui/ws/window_manager_display_root.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/ws/window_manager_display_root.h
diff --git a/services/ui/ws/window_manager_display_root.h b/services/ui/ws/window_manager_display_root.h
index d08dcecca4d2559ce62b2d816eb12f2779276270..a0a9b28b4ace281555a525929420d13a1568eaa7 100644
--- a/services/ui/ws/window_manager_display_root.h
+++ b/services/ui/ws/window_manager_display_root.h
@@ -32,18 +32,18 @@ class WindowManagerDisplayRoot {
// the display roots are automatically created this root is visible to the
// window manager. When the display roots are not automatically created this
// root has a single child that is created by the client. Use
// GetClientVisibileRoot() to get the root that is visible to the client.
ServerWindow* root() { return root_.get(); }
const ServerWindow* root() const { return root_.get(); }
// See root() for details of this. This returns null until the client creates
// the root.
- ServerWindow* GetClientVisibileRoot() {
+ ServerWindow* GetClientVisibleRoot() {
return const_cast<ServerWindow*>(
const_cast<const WindowManagerDisplayRoot*>(this)
- ->GetClientVisibileRoot());
+ ->GetClientVisibleRoot());
}
- const ServerWindow* GetClientVisibileRoot() const;
+ const ServerWindow* GetClientVisibleRoot() const;
Display* display() { return display_; }
const Display* display() const { return display_; }
« no previous file with comments | « services/ui/ws/cursor_unittest.cc ('k') | services/ui/ws/window_manager_display_root.cc » ('j') | no next file with comments »
@@ -32,18 +32,18 @@ class WindowManagerDisplayRoot {
// window manager. When the display roots are not automatically created this
// root has a single child that is created by the client. Use
- // GetClientVisibileRoot() to get the root that is visible to the client.
+ // GetClientVisibleRoot() to get the root that is visible to the client.
ServerWindow* root() { return root_.get(); }
const ServerWindow* root() const { return root_.get(); }

Powered by Google App Engine
This is Rietveld 408576698